import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class Input extends StatelessWidget {
  final TextEditingController controller;
  final String placeholder;
  final IconData icon;
  final bool isPassword;
  final bool isNumber;
  final Color backgroundColor;
  final Function onChange;
  final Color textColor;
  final Color boxShadowColor;

  Input(
      {@required this.controller,
      @required this.icon,
      @required this.placeholder,
      this.isPassword = false,
      this.isNumber = false,
      this.backgroundColor = Colors.white,
      this.boxShadowColor = Colors.black12,
      this.textColor = Colors.black,
      this.onChange(String text)});

  @override
  Widget build(BuildContext context) => Container(
        padding: EdgeInsets.only(top: 5, bottom: 5, left: 15, right: 15),
        margin: EdgeInsets.all(5),
        decoration: BoxDecoration(
            color: backgroundColor,
            borderRadius: BorderRadius.circular(15),
            boxShadow: [
              BoxShadow(
                  color: this.boxShadowColor.withOpacity(.2),
                  offset: Offset(.5, 8),
                  blurRadius: 10,
                  spreadRadius: 1)
            ]),
        child: TextField(
          cursorColor: Colors.black,
          controller: controller,
          obscureText: isPassword,
          style: TextStyle(color: Colors.black),
          maxLength: 600,
          onChanged: (this.onChange != null ? this.onChange : null),
          keyboardType: this.isNumber
              ? TextInputType.numberWithOptions(decimal: false)
              : TextInputType.text,
          decoration: InputDecoration(
              icon: Icon(icon, color: this.textColor),
              border: InputBorder.none,
              labelText: placeholder,
              counterText: "",
              labelStyle: TextStyle(color: Colors.black)),
        ),
      );
}
