import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

// ignore: must_be_immutable
class SkeletonText extends StatefulWidget {
  final double height;
  final double width;
  Color colors;

  SkeletonText(
      {Key key, this.height = 20, this.width = 200, this.colors = Colors.black})
      : super(key: key);

  createState() => SkeletonState();
}

class SkeletonState extends State<SkeletonText>
    with SingleTickerProviderStateMixin {
  AnimationController _controller;
  Animation gradientPosition;

  @override
  void initState() {
    _controller = AnimationController(
        duration: Duration(milliseconds: 1500), vsync: this);
    gradientPosition = Tween<double>(
      begin: -3,
      end: 10,
    ).animate(
      CurvedAnimation(parent: _controller, curve: Curves.linear),
    )..addListener(() {
        setState(() {});
      });

    _controller.repeat();
    super.initState();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: widget.width,
      height: widget.height,
      margin: EdgeInsets.only(top: 5, bottom: 5),
      decoration: BoxDecoration(
          gradient: LinearGradient(
              begin: Alignment(gradientPosition.value, 0),
              end: Alignment(-1, 0),
              colors: [
                widget.colors.withOpacity(.05),
                widget.colors.withOpacity(.1),
                widget.colors.withOpacity(.05)
              ]),
          borderRadius: BorderRadius.circular(25)),
    );
  }
}
